@@ -13,7 +13,7 @@
 # limitations under the License.
 
 # This script includes common functions for testing setup and teardown.
-source $(dirname $0)/../vendor/knative.dev/test-infra/scripts/e2e-tests.sh
+source $(dirname $0)/../vendor/knative.dev/hack/e2e-tests.sh
 
 export KOURIER_CONTROL_NAMESPACE=knative-serving
 export KOURIER_GATEWAY_NAMESPACE=kourier-system
@@ -41,7 +41,7 @@ function test_setup() {
 
   # Bringing up controllers.
   echo ">> Bringing up Kourier"
-  sed 's/--log-level info/--log-level debug/g' deploy/kourier-knative.yaml | ko apply -f - || return 1
+  ko resolve -f config | sed 's/--log-level info/--log-level debug/g' | ko apply -f - || return 1
 
   scale_deployment 3scale-kourier-control "${KOURIER_CONTROL_NAMESPACE}"
   scale_deployment 3scale-kourier-gateway "${GATEWAY_NAMESPACE_OVERRIDE}"
