@@ -23,19 +23,12 @@ ko resolve -f config | \
   kubectl apply -f -
 
 echo "Wait for all deployments to be up"
-for d in $(kubectl -n ${KOURIER_CONTROL_NAMESPACE} get deploy -oname)
-do
-  kubectl -n "${KOURIER_CONTROL_NAMESPACE}" wait --timeout=300s --for=condition=Available "$d"
-done
+kubectl -n "${KOURIER_CONTROL_NAMESPACE}" wait --timeout=300s --for=condition=Available deployments --all
+kubectl -n "${KOURIER_GATEWAY_NAMESPACE}" wait --timeout=300s --for=condition=Available deployments --all
 
-for d in $(kubectl -n ${KOURIER_GATEWAY_NAMESPACE} get deploy -oname)
-do
-  kubectl -n "${KOURIER_GATEWAY_NAMESPACE}" wait --timeout=300s --for=condition=Available "$d"
-done
-
-ips=( $(kubectl get nodes -lkubernetes.io/hostname!=kind-control-plane -ojsonpath='{.items[*].status.addresses[?(@.type=="InternalIP")].address}') )
+ip=$(kubectl get nodes -lkubernetes.io/hostname!=kind-control-plane -ojsonpath='{.items[*].status.addresses[?(@.type=="InternalIP")].address}' | head -n1)
 port=$(kubectl -n kourier-system get svc kourier -ojsonpath='{.spec.ports[?(@.name=="http2")].nodePort}')
 echo
-echo "You can connect to Kourier at ${ips[0]}:${port}"
-echo "Consider exporting it via 'export KOURIER_IP=${ips[0]}:${port}'"
+echo "You can connect to Kourier at ${ip}:${port}"
+echo "Consider exporting it via 'export KOURIER_IP=${ip}:${port}'"
 echo "Example usage: 'curl -H \"Host: helloworld-go.default.example.com\" \$KOURIER_IP'"
